@@ -14,10 +14,10 @@ impl<T> Payload for Binary<T> {
     const CONTENT_TYPE: &'static str = "application/octet-stream";
 
     fn schema_ref() -> MetaSchemaRef {
-        MetaSchemaRef::Inline(MetaSchema {
+        MetaSchemaRef::Inline(Box::new(MetaSchema {
             format: Some("binary"),
             ..MetaSchema::new("string")
-        })
+        }))
     }
 }
 
