@@ -2,7 +2,7 @@ use poem::web::Field as PoemField;
 use serde_json::Value;
 
 use crate::{
-    registry::MetaSchemaRef,
+    registry::{MetaSchemaRef, Registry},
     types::{
         ParseError, ParseFromJSON, ParseFromMultipartField, ParseFromParameter, ParseResult,
         ToJSON, Type, TypeName,
@@ -19,6 +19,10 @@ impl<T: Type> Type for Option<T> {
         T::schema_ref()
     }
 
+    fn register(registry: &mut Registry) {
+        T::register(registry);
+    }
+
     fn as_value(&self) -> Option<&Self::ValueType> {
         match self {
             Some(value) => Some(value),
